.icon {
  font-size: 16px;
  height: 16px;
  transition: none;
}

.iconWithLabel {
  margin-right: 4px;

  [dir='rtl'] & {
    margin-right: 0;
    margin-left: 4px;
  }
}

@keyframes iconSpin {
  100% {
    transform: rotate(360deg);
  }
}

.iconSpinning {
  animation: iconSpin 4s linear infinite;
}
