@import '../../../../scss/mixins';

.modalInner {
  width: 650px;
  min-height: 200px;
  display: flex;
  flex-direction: column;
  color: $textColorLight;

  p {
    @include copy;
  }
}

.closeButton {
  position: absolute;
  right: 10px;
  top: 10px;
  display: block;
  padding: 0;
  cursor: pointer;
  color: #919191;
  border: 0;
  background: transparent;

  [dir='rtl'] & {
    right: unset;
    left: 10px;
  }
}

.dismissIcon {
  @include dismiss;
}
